===========================================
``psyclone.domain.gocean.gocean_constants``
===========================================

.. automodule:: psyclone.domain.gocean.gocean_constants

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.gocean.gocean_constants


Classes
=======

- :py:class:`GOceanConstants`:
  This class stores all GOcean constants.


.. autoclass:: GOceanConstants
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: GOceanConstants
      :parts: 1
